@@ -18,12 +18,12 @@ import imp
 import io
 import itertools
 import logging
-import multiprocessing
 from numbers import Number
 import os
 import tempfile
 import string
 import sys
+import warnings
 
 from distutils.core import Extension
 
@@ -36,8 +36,8 @@ import numpy as np
 import pystan.api
 import pystan.misc
 
+logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger('pystan')
-logger.setLevel(logging.INFO)
 
 
 def load_module(module_name, module_path):
@@ -53,6 +53,34 @@ def load_module(module_name, module_path):
         return imp.load_module(module_name, *module_info)
 
 
+def _map_parallel(function, args, n_jobs):
+    """multiprocessing.Pool(processors=n_jobs).map with some error checking"""
+    # Following the error checking found in joblib
+    multiprocessing = int(n_jobs) not in (0, 1)
+    if multiprocessing:
+        try:
+            import multiprocessing
+            import multiprocessing.pool
+        except ImportError:
+            multiprocessing = None
+    # 2nd stage: validate that locking is available on the system and
+    #            issue a warning if not
+    if multiprocessing:
+        try:
+            _sem = multiprocessing.Semaphore()
+            del _sem  # cleanup
+        except (ImportError, OSError) as e:
+            multiprocessing = None
+            warnings.warn('%s. _map_parallel will operate in serial mode' % (e,))
+    if multiprocessing:
+        if n_jobs == -1:
+            n_jobs = None
+        mymap = multiprocessing.Pool(processes=n_jobs).map
+    else:
+        mymap = map
+    return list(mymap(function, args))
+
+
 # NOTE: StanModel instance stores references to a compiled, uninstantiated
 # C++ model.
 @implements_to_string
@@ -176,13 +204,16 @@ class StanModel:
     """
     def __init__(self, file=None, charset='utf-8', model_name="anon_model",
                  model_code=None, stanc_ret=None, boost_lib=None,
-                 eigen_lib=None, save_dso=True, verbose=False, **kwargs):
+                 eigen_lib=None, save_dso=True, verbose=False, obsfucate_model_name=False):
 
         if stanc_ret is None:
             stanc_ret = pystan.api.stanc(file=file,
+                                         charset=charset,
                                          model_code=model_code,
                                          model_name=model_name,
-                                         verbose=verbose, **kwargs)
+                                         verbose=verbose,
+                                         obsfucate_model_name=obsfucate_model_name)
+
         if not isinstance(stanc_ret, dict):
             raise ValueError("stanc_ret must be an object returned by stanc.")
         stanc_ret_keys = {'status', 'model_code', 'model_cppname',
@@ -200,7 +231,7 @@ class StanModel:
         self.save_dso = save_dso
 
         msg = "COMPILING THE C++ CODE FOR MODEL {} NOW."
-        logger.warning(msg.format(self.model_name))
+        logger.info(msg.format(self.model_name))
         if verbose:
             msg = "OS: {}, Python: {}, Cython {}".format(sys.platform,
                                                          sys.version,
@@ -461,7 +492,7 @@ class StanModel:
     def sampling(self, data=None, pars=None, chains=4, iter=2000,
                  warmup=None, thin=1, seed=None, init='random',
                  sample_file=None, diagnostic_file=None, verbose=False,
-                 algorithm=None, control=None, n_jobs=1, **kwargs):
+                 algorithm=None, control=None, n_jobs=-1, **kwargs):
         """Draw samples from the model.
 
         Parameters
@@ -555,10 +586,9 @@ class StanModel:
 
             - `max_treedepth` : int, positive
 
-        n_jobs : int, 1 by default
-            Sample in parallel. If -1 all CPUs are used. If 1 is given, no
-            parallel computing code is used at all, which is useful for
-            debugging.
+        n_jobs : int, optional
+            Sample in parallel. If -1 all CPUs are used. If 1, no parallel
+            computing code is used at all, which is useful for debugging.
 
         Returns
         -------
@@ -568,7 +598,7 @@ class StanModel:
         Other parameters
         ----------------
 
-        chain_id : int, optional
+        chain_id : int or iterable of int, optional
             `chain_id` can be a vector to specify the chain_id for all chains or
             an integer. For the former case, they should be unique. For the latter,
             the sequence of integers starting from the given `chain_id` are used
@@ -637,25 +667,20 @@ class StanModel:
         n_kept = 1 + (iter - warmup - 1) // thin
         n_save = n_kept + warmup2
 
-        if n_jobs == -1:
-            n_jobs = None
+        if n_jobs is None:
+            n_jobs = -1
 
         assert len(args_list) == chains
         call_sampler_args = izip(itertools.repeat(data), args_list)
         call_sampler_star = self.module._call_sampler_star
-        if n_jobs is None or n_jobs > 1:
-            pool = multiprocessing.Pool(processes=n_jobs)
-            # in Python 3.3 and higher one could use pool.starmap
-            ret_and_samples = pool.map(call_sampler_star, call_sampler_args)
-        else:
-            ret_and_samples = [call_sampler_star(a) for a in call_sampler_args]
+        ret_and_samples = _map_parallel(call_sampler_star, call_sampler_args, n_jobs)
         samples = [smpl for _, smpl in ret_and_samples]
 
         inits_used = pystan.misc._organize_inits([s['inits'] for s in samples],
                                                  m_pars, p_dims)
 
         random_state = np.random.RandomState(args_list[0]['seed'])
-        perm_lst = [random_state.permutation(n_kept) for _ in range(chains)]
+        perm_lst = [random_state.permutation(int(n_kept)) for _ in range(chains)]
         fnames_oi = fit._get_param_fnames_oi()
         n_flatnames = len(fnames_oi)
         fit.sim = {'samples': samples,
