@@ -341,6 +341,22 @@ namespace stan {
                 RNG& rng) {
       using boost::variate_generator;
       using boost::random::weibull_distribution;
+
+      static const char* function = "stan::prob::weibull_rng(%1%)";
+
+      using stan::math::check_finite;
+      using stan::math::check_not_nan;
+      using stan::math::check_positive;
+  
+      if(!check_finite(function, alpha, "Shape parameter"))
+        return 0;
+      if(!check_positive(function, alpha, "Shape parameter"))
+        return 0;
+      if(!check_not_nan(function, sigma, "Scale parameter"))
+        return 0;
+      if(!check_positive(function, sigma, "Scale parameter"))
+        return 0;
+
       variate_generator<RNG&, weibull_distribution<> >
         weibull_rng(rng, weibull_distribution<>(alpha, sigma));
       return weibull_rng();
