@@ -12,7 +12,8 @@
 #include <stan/prob/traits.hpp>
 #include <stan/prob/constants.hpp>
 #include <stan/prob/internal_math.hpp>
-
+#include <stan/prob/distributions/univariate/continuous/gamma.hpp>
+#include <stan/prob/distributions/univariate/discrete/poisson.hpp>
 #include <stan/math/functions/binomial_coefficient_log.hpp>
 
 namespace stan {
@@ -596,11 +597,23 @@ namespace stan {
                      RNG& rng) {
       using boost::variate_generator;
       using boost::random::negative_binomial_distribution;
-      variate_generator<RNG&, negative_binomial_distribution<> >
-        neg_binomial_rng(rng, 
-                         negative_binomial_distribution<>(alpha,
-                                                          beta / (beta + 1)));
-      return neg_binomial_rng();
+
+      static const char* function = "stan::prob::neg_binomial_rng(%1%)";
+
+      using stan::math::check_finite;      
+      using stan::math::check_positive;
+
+      if (!check_finite(function, alpha, "Shape parameter"))
+        return 0;
+      if (!check_positive(function, alpha, "Shape parameter"))
+        return 0;
+      if (!check_finite(function, beta, "Inverse scale parameter"))
+        return 0;
+      if (!check_positive(function, beta, "Inverse scale parameter"))
+        return 0;
+
+      return stan::prob::poisson_rng(stan::prob::gamma_rng(alpha,1.0 / beta,
+                                                           rng),rng);
     }
   }
 }
