@@ -125,11 +125,11 @@ TEST(MetaTraits, length) {
 
   Eigen::Matrix<double,Eigen::Dynamic,1> rv(2);
   rv << 1, 2;
-  EXPECT_EQ(2, length(rv));
+  EXPECT_EQ(2U, length(rv));
 
   Eigen::Matrix<double,1,Eigen::Dynamic> v(2);
   v << 1, 2;
-  EXPECT_EQ(2, length(v));
+  EXPECT_EQ(2U, length(v));
 }
 
 TEST(MetaTraits, get) {
