@@ -3,9 +3,14 @@
 #include <boost/random/mersenne_twister.hpp>
 #include<boost/math/distributions.hpp>
 
-TEST(ProbDistributionsBernoulli, random) {
+TEST(ProbDistributionsBernoulli, error_check) {
   boost::random::mt19937 rng;
   EXPECT_NO_THROW(stan::prob::bernoulli_rng(0.6,rng));
+
+  EXPECT_THROW(stan::prob::bernoulli_rng(1.6,rng),std::domain_error);
+  EXPECT_THROW(stan::prob::bernoulli_rng(-0.6,rng),std::domain_error);
+  EXPECT_THROW(stan::prob::bernoulli_rng(stan::math::positive_infinity(),rng),
+               std::domain_error);
 }
 
 TEST(ProbDistributionsBernoulli, chiSquareGoodnessFitTest) {
